<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://oakandbeech.com
 * @since      1.0.0
 *
 * @package    User_Sync_For_Klaviyo
 * @subpackage User_Sync_For_Klaviyo/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    User_Sync_For_Klaviyo
 * @subpackage User_Sync_For_Klaviyo/public
 * @author     Oak and Beech <info@oakandbeech.com>
 */
class User_Sync_For_Klaviyo_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	// The Klaviyo public key
	private $public_key;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version, $public_key ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		$this->public_key = $public_key;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in User_Sync_For_Klaviyo_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The User_Sync_For_Klaviyo_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/user-sync-for-klaviyo-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in User_Sync_For_Klaviyo_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The User_Sync_For_Klaviyo_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		// wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/user-sync-for-klaviyo-public.js', array( 'jquery' ), $this->version, false );
		wp_enqueue_script('klaviyo-onsite','//static.klaviyo.com/onsite/js/klaviyo.js?company_id='.$this->public_key, null, null, true);
		add_filter('script_loader_tag',array($this,'add_async_to_script'), 1, 3);
	}

	// for some bonkers reason, wordpress doesn't let you add async to a script
	function add_async_to_script($tag, $handle, $src)
	{	
		if($handle == 'klaviyo-onsite'){
			return "<script async src='" . $src . "'></script>";
		}else{
			return $tag;
		}
	}
}
